@@ -3,8 +3,6 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "4.4.0"
-__all__ = ['Model', 'Wizard', 'Report']
 import sys
 try:
     import cdecimal
@@ -21,6 +19,9 @@ from decimal import Decimal
 
 import proteus.config
 
+__version__ = "4.6.1"
+__all__ = ['Model', 'Wizard', 'Report']
+
 _MODELS = threading.local()
 
 
@@ -545,6 +546,8 @@ class ModelList(list):
                 definition = record._fields[self.parent_name]
                 if definition['type'] in ('many2one', 'reference'):
                     setattr(record, self.parent_name, self.parent)
+        self.record_removed.difference_update(records)
+        self.record_deleted.difference_update(records)
 
     def append(self, record):
         self.__check([record])
@@ -617,6 +620,36 @@ class ModelList(list):
         with Relation._config.set_context(self._get_context()):
             return Relation.find(new_domain, offset, limit, order)
 
+    def set_sequence(self, field='sequence'):
+        changed = False
+        prev = None
+        for record in self:
+            if prev:
+                index = getattr(prev, field)
+            else:
+                index = None
+            update = False
+            value = getattr(record, field)
+            if value is None:
+                if index:
+                    update = True
+                elif prev and record.id >= 0:
+                    update = record.id < prev.id
+            if value == index:
+                if prev and record.id >= 0:
+                    update = record.id < prev.id
+            elif value <= (index or 0):
+                update = True
+            if update:
+                if index is None:
+                    index = 0
+                index += 1
+                setattr(record, field, index)
+                changed = record
+            prev = record
+        if changed:
+            self._changed()
+
 
 class Model(object):
     'Model class for Tryton records'
@@ -710,6 +743,9 @@ class Model(object):
     def __hash__(self):
         return hash(self.__class__.__name__) ^ hash(self.id)
 
+    def __int__(self):
+        return self.id
+
     @property
     def id(self):
         'The unique ID'
